#/bin/bash
## Script per crear noves unitats de xarxa en SAMBA al servidor de centre Linkat edu 14.04 o superior.
## Desenvolupat per Pablo Vigo <pvigo#xtec.cat> <pablo.vigo#ticxcat.cat>

RUTA="/usr/share/linkat/linkat-nova-unitat"
. /etc/linkat/linkat-servidor/linkat-servidor.conf

if [ -f /etc/linkat/linkat-servidor/linkat-servidor.conf ] && [ -f /etc/modalitat_linkat ]; then
	. /etc/linkat/linkat-servidor/linkat-servidor.conf
else
	zenity --width="400" --error --title="No es poden afegir noves unitats" --text="El servidor de centre encara no ha sigut configurat o l'usuari no és administrador del sistema."
	exit 2
fi

zenity --width="400" --question --title="Nova unitat de xarxa SAMBA" --text="Aquest programa permet crear noves unitats de xarxa SAMBA al servidor de centre Linkat.\n\nVoleu continuar?"
if [ "$?" -gt 0 ] ; then
	exit 1
fi 

LOOP=0

while [ "$LOOP" -eq 0 ]
do

export TEMPDIR=$(mktemp -d)

res=$(zenity --forms --title="Unitats de xarxa SAMBA" --text="Nova unitat" --add-entry="Nom de la unitat" --add-entry="Grup LDAP")
if [ "$?" -gt 0 ]; then
	exit 1
fi

NOVAUNITAT=$(echo $res | awk 'BEGIN { FS="|"; } {print $1; }')
NOUGRUP=$(echo $res | awk 'BEGIN { FS="|"; } {print $2; }')

if [ "$NOVAUNITAT" == "" ] || [ "$NOUGRUP" == "" ] ; then
	zenity --width="350" --error --text="S'ha d'introduir un nom d'unitat i un nom de grup."
	exit 2
fi

for i in "$NOVAUNITAT" "$NOUGRUP"
do
  echo "$i" | grep -E " "
  if [ "$?" -eq 0 ]; then
    zenity --width="250" --error --text="No es poden fer servir espais."
    exit 2
  fi
done

res=$(grep -R "^\[$NOVAUNITAT\]" /etc/samba/)
if [ "$?" -eq 0 ]; then
  zenity --width="300" --info --title="Unitats de xarxa SAMBA" --text="Aquesta unitat de xarxa ja existeix al servidor.\n\nEl programa s'aturarà."
  exit 1
fi

## Creant el nou grup LDAP

ldapsearch -xLL -b dc=$NEW_DOMAIN | egrep cn: | sed "s/cn: //g" > $TEMPDIR/grupldap.list
res=$(grep "^$NOUGRUP$" "$TEMPDIR"/grupldap.list)
        if [ "$?" -eq 0 ] ; then
          echo "Grup existent"
        else
          echo "Grup nou"
        GIDN=$(ldapsearch -xLL -b dc=$NEW_DOMAIN | egrep gidNumber | awk -F: '{print $2}' | sort -n | tail -1)
        NOUGIDN=$(($GIDN + 1))
	cp -av "$RUTA"/nougrup.ldif.linkat "$RUTA"/nougrup.ldif
        	sed -i s/_NOUGRUP_/"$NOUGRUP"/g "$RUTA"/nougrup.ldif
           	sed -i s/_DOMINI_/"$NEW_DOMAIN"/g "$RUTA"/nougrup.ldif
           	sed -i s/_NOUGIDN_/"$NOUGIDN"/g "$RUTA"/nougrup.ldif
	cp -av "$RUTA"/afegirnougrup.linkat "$TEMPDIR"/afegirnougrup
		sed -i s/_DOMINI_/"$NEW_DOMAIN"/g "$TEMPDIR"/afegirnougrup
        	sed -i s/_PASSWDLDAP_/"$NEW_PASSROOT"/g "$TEMPDIR"/afegirnougrup
	chmod +x "$TEMPDIR"/afegirnougrup
	"$TEMPDIR"/afegirnougrup

        fi

## Creant unitat de xarxa
## Verificant si existeix als fitxers de configuració
res=$(grep -R "^\[$NOVAUNITAT\]" /etc/samba/)
if [ "$?" -eq 0 ]; then
  zenity --width="300" --info --title="Unitats de xarxa SAMBA" --text="Aquesta unitat de xarxa ja existeix al servidor.\n\nEl programa s'aturarà."
  exit 1
else

## Creant la nova unitat
  mkdir -m 2770 /srv/exports/$NOVAUNITAT
  chown root:$NOUGRUP /srv/exports/$NOVAUNITAT
  chmod -R 2770 /srv/exports/$NOVAUNITAT
  mkdir -p /srv/exports/Paperera/Paperera_Unitat_$NOVAUNITAT
  chmod -R 2770 /srv/exports/Paperera/Paperera_Unitat_$NOVAUNITAT
  chown -R root:$NOUGRUP /srv/exports/Paperera/Paperera_Unitat_$NOVAUNITAT
  setfacl --set-file=/usr/share/linkat/linkat-nova-unitat/plantilla-acl /srv/exports/$NOVAUNITAT > /dev/null 2>&1
  getfacl -p /srv/exports/$NOVAUNITAT | setfacl --set-file=- /srv/exports/Paperera/Paperera_Unitat_$NOVAUNITAT > /dev/null 2>&1
  chgrp -R $NOUGRUP /srv/exports/$NOVAUNITAT
fi

## Configurant el SAMBA
## Adaptant el nou fitxer novaunitat.conf
cp -av "$RUTA"/unitat.conf.linkat $TEMPDIR/$NOVAUNITAT.conf
sed -i s/_NOVAUNITAT_/$NOVAUNITAT/g $TEMPDIR/$NOVAUNITAT.conf
sed -i s/_NOUGRUP_/$NOUGRUP/g $TEMPDIR/$NOVAUNITAT.conf

## Copiant nou fitxer novaunitat.conf
if [ ! -d /etc/samba/smb.conf.d/ ] ; then
	mkdir -p /etc/samba/smb.conf.d/
fi
cp -av $TEMPDIR/$NOVAUNITAT.conf /etc/samba/smb.conf.d/

## Afegint nova linia a SMB.CONF
echo "include = /etc/samba/smb.conf.d/$NOVAUNITAT.conf" >> /etc/samba/smb.conf

## Creant històric
if [ ! -d /usr/share/linkat/linkat-nova-unitat/unitats ]; then
        mkdir /usr/share/linkat/linkat-nova-unitat/unitats
fi
echo "UNITAT=$NOVAUNITAT" > /usr/share/linkat/linkat-nova-unitat/unitats/$NOVAUNITAT
echo "GRUP=$NOUGRUP" >> /usr/share/linkat/linkat-nova-unitat/unitats/$NOVAUNITAT

## Eliminant el directori temporal
rm -rf $TEMPDIR
rm -rf "$RUTA"/nougrup.ldif

## Reniciant el servei SAMBA
service nmbd restart
service smbd restart

zenity --width="250" --info --text="La unitat de xarxa $NOVAUNITAT ha estat creada correctament."

zenity --width="350"  --question --title="Unitat de xarxa SAMBA" --text="Voleu afegir-hi una altra unitat de xarxa?"
if [ "$?" -gt 0 ]; then
        LOOP=1
fi

done

